@@ -737,12 +737,13 @@ int sow (void)
 
    readfile(".", ".serial", serialbuf);
    argv_snfetch[argc_snfetch++] = serialbuf;
-   if (!strcmp(serialbuf, "0"))   /* Bugfix: It's a string, not an int... */
+   if (*serialbuf == '\0')
    {
       LOG3("sow:couldn't get a value from %s/.serial:%m?", jp->group);
       strcpy(serialbuf, "0");
-      argv_snfetch[argc_snfetch++] = (optmax ? optmax : "200");
    }
+   if (strcmp(serialbuf, "0") == 0)
+      argv_snfetch[argc_snfetch++] = (optmax ? optmax : "200");
    else
    {
       readfile(".", ".max", maxbuf);
