@@ -17,7 +17,7 @@ static const char rcsid[] = "$Id$";
 
 char *snroot = SNROOT;
 uid_t snuid;
-uid_t sngid;
+gid_t sngid;
 
 void parameters (int wantwriteperms)
 {
