@@ -9,8 +9,8 @@
 #define PARAMETERS_H
 
 extern char *snroot;
-extern unsigned snuid;
-extern unsigned sngid;
+extern uid_t snuid;
+extern gid_t sngid;
 
 extern void parameters (int wantwriteperms);
 
