@@ -156,10 +156,10 @@ static int store_local (char *group)
    d.messageid = messageid;
    if (group)
       if (check_exist)
-         if (0 == dh_find(&d))
+         if (0 == dh_find(&d, FALSE))
             if (0 == strcasecmp(group, d.newsgroup))
             {
-               LOG1("store_local:\"%s\" already exists in %s, not storing", messageid, group);
+               LOG1("store_local:<%s> already exists in %s, not storing", messageid, group);
                return (1);
             }
    d.serial = sto_add(group ? group : JUNK_GROUP, &art);
@@ -179,10 +179,10 @@ static int store_local (char *group)
       {
          if (EEXIST == errno)
          {
-            LOG1("store_local:oops, stored \"%s\" but it already exists", messageid);
+            LOG1("store_local:oops, stored <%s> but it already exists", messageid);
          }
          else
-            log("store_local:can't insert in db for \"%s\" in %s:%d, %m?",
+            log("store_local:can't insert in db for <%s> in %s:%d, %m?",
                 messageid, group, d.serial);
       }
    }
@@ -679,7 +679,7 @@ static int read_rnews (void)
    if (0 == consumed) eof();
    if (consumed < 0) badread();
 
-   for (body_lines = 0;;)
+   for (body_lines = 0; consumed < bytes; )
    {
       if (0 == (c = getline())) eof();
       consumed += c;
@@ -689,8 +689,6 @@ static int read_rnews (void)
       if ('.' == *rline)
          if (b_appendl(&body, ".", 1)) nomem();
       appendbody();
-      if (consumed == bytes)
-         break;
    }
    return (consumed);
 }
@@ -773,7 +771,7 @@ int read_article (int rnews)
       memcpy(p, days[tmp->tm_wday], 3);
       appendhead("Date: ", sizeof ("Date: ") - 1);
       appendhead(p, strlen(p));
-      appendhead(" GMT\r\n", 6);
+      appendhead(" -0000\r\n", 8);
       LOG3("added Date to article \"%s\"", messageid);
    }
 
